Google Maps › Advanced Route — Stisla

Stisla
St

- Dashboard
- Dashboard
  - General Dashboard
  - Ecommerce Dashboard
- Starter
- Layout
  - Default Layout
  - Transparent Sidebar
  - Top Navigation
- Blank Page
- Bootstrap
  - Alert
  - Badge
  - Breadcrumb
  - Buttons
  - Card
  - Carousel
  - Collapse
  - Dropdown
  - Form
  - List Group
  - Media Object
  - Modal
  - Nav
  - Navbar
  - Pagination
  - Popover
  - Progress
  - Table
  - Tooltip
  - Typography
- Stisla
- Components
  - Article
  - Avatar
  - Chat Box
  - Empty State
  - Gallery
  - Hero
  - Multiple Upload
  - Pricing
  - Statistic
  - Tab
  - Table
  - User
  - Wizard
- Forms
  - Advanced Form
  - Editor
  - Validation
- Google Maps
  - Advanced Route
  - Draggable Marker
  - Geocoding
  - Geolocation
  - Marker
  - Multiple Marker
  - Route
  - Simple
- Modules
  - Calendar
  - ChartJS
  - DataTables
  - Flag
  - Font Awesome
  - Ion Icons
  - Owl Carousel
  - Sparkline
  - Sweet Alert
  - Toastr
  - Vector Map
  - Weather Icon
- Pages
- Auth
  - Forgot Password
  - Login
  - Login 2
  - Register
  - Reset Password
- Errors
  - 503
  - 403
  - 404
  - 500
- Features
  - Activities
  - Post Create
  - Posts
  - Profile
  - Settings
  - Setting Detail
  - Tickets
- Utilities
  - Contact
  - Invoice
  - Subscribe
- Credits

Documentation

# Advanced Route

Dashboard
Google Maps
Advanced Route

## Advanced Route

The same as the 'route' example, but in this example it will be a bit cooler. Click the 'Start Travel' button to start seeing magic.

#### Advanced Routes

Start Travel